
# Run ipython with command 
# ipython -q4thread

import anatomist.api as ana
a = ana.Anatomist()
import os
src="<TO BE FILLED>/formationJIRFNI_2010/jirfni_2010/data" # directory including "data_for_anatomist"

# Load activations image
activations = a.loadObject( os.path.join(src, "data_for_anatomist", "subject01", "Audio-Video_T_map.nii") )

# Load white matter meshes
left_whitematter = a.loadObject( os.path.join(src, "data_for_anatomist", "subject01", "subject01_Lwhite.mesh") )
right_whitematter = a.loadObject( os.path.join(src, "data_for_anatomist", "subject01", "subject01_Rwhite.mesh") )

# Load brain mask
brain_mask = a.loadObject(os.path.join(src, "data_for_anatomist", "subject01", "brain_subject01.nii"))

# Load head mesh
head = a.loadObject(os.path.join(src, "data_for_anatomist", "subject01", "subject01_head.mesh"))

# Change color palette for brain mask
brain_mask.setPalette(a.getPalette("BLUE-ufusion"))

# Create a SAGITTAL window
w2 = a.createWindow( 'Sagittal' )

# Apply SPM/NIFTi referential to images and meshes
brain_mask.applyBuiltinReferential()
activations.applyBuiltinReferential()
left_whitematter.applyBuiltinReferential()
right_whitematter.applyBuiltinReferential()
head.applyBuiltinReferential()

# Change color palette for activations
activations.setPalette("tvalues100-200-100")

# Make 2 fusions: one for left hemisphere and another for right hemisphere
left_fusion = a.fusionObjects( [activations, left_whitematter], "Fusion3DMethod" )
right_fusion = a.fusionObjects( [activations, right_whitematter], "Fusion3DMethod" )

# Add the two 3D fusions into the window
w2.addObjects( left_fusion )
w2.addObjects( right_fusion )

# Add the brain mask
w2.addObjects( brain_mask )

# Add the head mesh
head.addInWindows(w2)

# Change head mesh transparency
material = a.Material(diffuse=[1, 1, 1, 0.3]) # 0.3 transparency
head.setMaterial(material)

w2.close()
del w2

exit()

