# -*- coding: utf-8 -*-
from neuroProcesses import *
import neuroConfig
from brainvisa import anatomist
import numpy

signature = Signature(
  'image', ReadDiskItem( '4D Volume', 'Aims readable volume formats' ),
  'sphere_size', Integer(),
)


def initialization( self ):
  self.sphere_size = 5



def execution( self, context ):
  # Read input image
  aims_image = aims.read( self.image.fullPath() )
  numpy_matrix = numpy.array( aims_image, copy = False )
  max_coordinate = [ int(i) for i in numpy.unravel_index( numpy_matrix.argmax(), numpy_matrix.shape ) ]
  context.write( 'Numpy says max is', aims_image.at( *max_coordinate ), 'at', max_coordinate )

  aims_sphere = aims.read( os.path.join( neuroConfig.dataPath[0].directory, 'standardmeshes', 'ico100_7.mesh') )
  
  # Change the size of the sphere and center it on image maximum
  voxel_size = aims_image.header()[ 'voxel_size' ]
  for vertex in aims_sphere.vertex():
    vertex *= self.sphere_size / 100.0
    vertex[ 0 ] += max_coordinate[ 0 ] * voxel_size[ 0 ]
    vertex[ 1 ] += max_coordinate[ 1 ] * voxel_size[ 1 ]
    vertex[ 2 ] += max_coordinate[ 2 ] * voxel_size[ 2 ]
  
  # Create a temporary file name for the modified sphere
  diskitem_sphere = context.temporary( 'Mesh Mesh' )
  
  # Write the modified sphere in temporary file
  aims.write( aims_sphere, diskitem_sphere.fullPath() )


  # Create an interpolator on the image to be able to get a value for any millimeter coordinate
  interpolator = aims.getLinearInterpolator( aims_image )
  
  # Create a texture on the sphere that takes the value from the interpolator for each point of the sphere
  vertices_count = aims_sphere.vertex().size()
  aims_texture = aims.Texture_FLOAT( vertices_count )
  for i in xrange( vertices_count ):
    aims_texture[ i ] = interpolator.value( *aims_sphere.vertex()[ i ] )
  
  # Write the created texture to a temporary file
  diskitem_texture = context.temporary( 'Texture' )
  aims_time_texture = aims.TimeTexture_FLOAT()
  aims_time_texture[ 0 ] = aims_texture
  aims.write( aims_time_texture, diskitem_texture.fullPath() )
  
  
  
  # Open Anatomist
  a = anatomist.Anatomist()
  # Load sphere in anatomist from temporary file
  aSphere = a.loadObject( diskitem_sphere.fullPath() )
  # Load sphere texture in anatomist from temporary file
  aTexture = a.loadObject( diskitem_texture.fullPath() )
  # Fusion sphere and texture to create a textured object
  aTexturedSphere = a.fusionObjects( (aSphere, aTexture), 'FusionTexSurfMethod' )
  # Load image in anatomist
  aImage = a.loadObject( self.image.fullPath() )
  # Create an Axial window
  aWindow = a.createWindow( 'Axial' )
  # Display textured sphere and image in window
  aWindow.addObjects( (aTexturedSphere, aImage) )
  # Move Anatomist cursor to the center of the voxel with maximum value
  aWindow.moveLinkedCursor( ( max_coordinate[ 0 ] * voxel_size[ 0 ],
                              max_coordinate[ 1 ] * voxel_size[ 1 ],
                              max_coordinate[ 2 ] * voxel_size[ 2 ] ) )

  # Return objects that must not be destroyed immediately
  return [ aTexturedSphere, aImage, aWindow ]
  